summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndrew Dolgov <[email protected]>2021-03-09 16:59:25 +0300
committerAndrew Dolgov <[email protected]>2021-03-09 16:59:25 +0300
commit9df7cbd5299359413d04233860031ae008c5b152 (patch)
treebffa75e2dd8e995952581d2aaad3f44b805f7a28
parent7a57bb1610c935ad7edb243a959b8558a0bfcdfd (diff)
don't bother with updateTitle()
-rw-r--r--init.js15
1 files changed, 3 insertions, 12 deletions
diff --git a/init.js b/init.js
index dd3d780..4689d89 100644
--- a/init.js
+++ b/init.js
@@ -1,4 +1,4 @@
/* global require, App, Feeds */
require(['dojo/_base/kernel', 'dojo/ready'], function (dojo, ready) {
ready(function() {
@@ -46,21 +46,12 @@ require(['dojo/_base/kernel', 'dojo/ready'], function (dojo, ready) {
link.href = canvas.toDataURL("image/x-icon");
};
}
-
-
});
}
- App.updateTitle = function() {
- let tmp = "Tiny Tiny RSS";
-
- if (App.global_unread > 0) {
- tmp = "(" + App.global_unread + ") " + tmp;
- }
-
+ PluginHost.register(PluginHost.HOOK_COUNTERS_PROCESSED, () => {
updateFaviconBadge(App.global_unread, Feeds.getUnread(-3, 0));
+ });
- document.title = tmp;
- }
});
});
@@ -1,4 +1,4 @@
-/* global require, App, Feeds */
+/* global require, App, Feeds, PluginHost */
require(['dojo/_base/kernel', 'dojo/ready'], function (dojo, ready) {
ready(function() {